package com.example.nto.controller;

import com.example.nto.entity.Employee;
import com.example.nto.service.EmployeeService;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;
import java.util.Optional;

@RestController
@RequestMapping("/api") // база
public class EmployeeController {

    private final EmployeeService employeeService;

    public EmployeeController(EmployeeService employeeService) {
        this.employeeService = employeeService;
    }

    @GetMapping("/auth") // Проверка аутентификации
    public ResponseEntity<?> authenticate() {
        return ResponseEntity.ok("Authenticated successfully");
    }

    @GetMapping("/{login}/info") // Получение информации о сотруднике
    public ResponseEntity<?> getInfo(@PathVariable String login) {
        Optional<Employee> employee = employeeService.findByLogin(login);
        if (employee.isPresent()) {
            return ResponseEntity.ok(employee.get());
        } else {
            return ResponseEntity.status(HttpStatus.NOT_FOUND).body("Employee not found");
        }
    }

    @PatchMapping("/{login}/open") // Открыть дверь
    public ResponseEntity<?> openDoor(@PathVariable String login, @RequestBody Map<String, Long> payload) {
        Long code = payload.get("value");

        if (code == null) {
            return ResponseEntity.status(HttpStatus.BAD_REQUEST).body("Invalid payload");
        }

        Optional<Employee> employee = employeeService.findByLogin(login);
        if (employee.isEmpty()) {
            return ResponseEntity.status(HttpStatus.BAD_REQUEST).body("Invalid login");
        }

        if (employeeService.validateCode(login, code)) {
            return ResponseEntity.ok("Door opened");
        } else {
            return ResponseEntity.status(HttpStatus.BAD_REQUEST).body("Invalid code");
        }
    }

    @GetMapping("/workers") // Получить всех сотрудников
    public ResponseEntity<List<Employee>> getAllWorkers() {
        List<Employee> allEmployees = employeeService.findAll(); // Получить всех сотрудников
        return ResponseEntity.ok(allEmployees);
    }
}